@@ -40,13 +40,23 @@ json_chunk_name = "json" + chunk_name
 output_jsons = str(data_output_dir_path / json_chunk_name)
 create_summary(output_jsons, str(data_output_dir_path / summary_filename))
 
-
 dstore = Datastore.get(workspace, save_datastore_name)
 dataset = Dataset.File.upload_directory(
-    src_dir=str(data_output_dir_path), target=DataPath(dstore, save_datastore_path), pattern="*.json", show_progress=True,
+    src_dir=str(data_output_dir_path), target=DataPath(dstore, save_datastore_path), pattern="*", show_progress=True,
     overwrite=True
 )
 
+dir_list = [p for p in Path(output_jsons).iterdir() if p.is_dir()]
+
+for dir_path in dir_list:
+    dir_name = dir_path.name
+    source = str(data_output_dir_path / dir_name)
+    destination = str(Path(save_datastore_path) / dir_name)
+    dataset = Dataset.File.upload_directory(
+        src_dir=source, target=DataPath(dstore, destination), pattern="*",
+        show_progress=True,
+        overwrite=True
+    )
 
 # End the run
 run.complete()
